.. _Tutorial3Demo:

==========
Tutorial 3
==========

Plotting a histogram
====================

.. report:: Tutorial3.WordCounter
   :render: line-plot
   :transform: histogram
   :tf-range: 0,100,1
   :as-lines:

   Word sizes in .py and .rst files. 

